@@ -1,7 +1,7 @@
 import unittest
 import os
 
-from tests.config_reader import read_db_config, read_tazendra_config
+from tests.config_reader import read_db_config, load_env_file
 from wbtools.lib.nlp.entity_extraction.email_addresses import get_email_addresses_from_text
 from wbtools.literature.corpus import CorpusManager
 
@@ -18,13 +18,11 @@ class TestEmailAddresses(unittest.TestCase):
                                                      "local_config", "db.cfg")), "Test DB config file not present")
     def test_get_email_addresses_from_paper(self):
         config = read_db_config()
-        tazendra_config = read_tazendra_config()
+        load_env_file()
         cm = CorpusManager()
         cm.load_from_wb_database(db_name=config["wb_database"]["db_name"], db_user=config["wb_database"]["db_user"],
                                  db_password=config["wb_database"]["db_password"],
                                  db_host=config["wb_database"]["db_host"],
-                                 file_server_user=tazendra_config["file_server"]["user"],
-                                 file_server_passwd=tazendra_config["file_server"]["password"],
                                  paper_ids=['00062455'])
         email_addresses = get_email_addresses_from_text(cm.get_paper('00062455').get_text_docs(
             include_supplemental=False, return_concatenated=True))
