@@ -13,10 +13,10 @@ class TestGenericNLP(unittest.TestCase):
 
     def setUp(self) -> None:
         config = read_db_config()
-        db_manager = WBGenericDBManager(
+        self.db_manager = WBGenericDBManager(
             dbname=config["wb_database"]["db_name"], user=config["wb_database"]["db_user"],
             password=config["wb_database"]["db_password"], host=config["wb_database"]["db_host"])
-        self.ntt_extractor = NttExtractor(db_manager=db_manager)
+        self.ntt_extractor = NttExtractor(db_manager=self.db_manager)
 
     def test_extract_entities(self):
         text = "  g2 is a new variant"
@@ -29,6 +29,18 @@ class TestGenericNLP(unittest.TestCase):
         strains = self.ntt_extractor.extract_all_entities_by_type(text, EntityType.STRAIN, match_curated=True)
         self.assertEqual(len(strains), 2)
 
+    def test_get_species_from_text(self):
+        text = "C. elegans is a model organism. C. elegans, C. elegans and C. elegans. C. elegans (1), C. elegans [2], " \
+               "C. tropicalis, D. melanogaster, Drosophila melanogaster, D.melanogaster"
+        species = self.ntt_extractor.extract_species_regex(text=text,
+                                                           taxon_id_name_map=self.db_manager.get_taxon_id_names_map(),
+                                                           blacklist=["4853"],
+                                                           whitelist=["Homo sapiens"],
+                                                           min_matches=2)
+        self.assertTrue(len(species) == 2 and
+                        "Caenorhabditis elegans" in species and
+                        "Drosophila melanogaster" in species)
+
 
 if __name__ == '__main__':
     unittest.main()
