@@ -13,6 +13,15 @@ class WBPaperDBManager(AbstractWBDBManager):
         super().__init__(dbname, user, password, host)
         self.person_db_manager = WBPersonDBManager(dbname, user, password, host)
 
+    def get_paper_curie(self, paper_id):
+        with self.get_cursor() as curs:
+            curs.execute(f"SELECT pap_identifier from pap_identifier WHERE joinkey = '{paper_id}' AND pap_identifier "
+                         f"LIKE 'AGRKB:%'")
+            res = curs.fetchone()
+            if res:
+                return res[0]
+            return None
+
     def get_paper_abstract(self, paper_id):
         return self._get_single_field(join_key=paper_id, field_name="pap_abstract")
 
@@ -112,7 +121,7 @@ class WBPaperDBManager(AbstractWBDBManager):
     def is_paper_positive_for_class(automated_classification_values: List[Tuple[str, str]], cl: str,
                                     min_value: str = 'medium'):
         scale = {"neg": 0, "low": 1, "medium": 2, "high": 3}
-        if cl in automated_classification_values:
+        if cl in set([datatype_value[0] for datatype_value in automated_classification_values]):
             return scale[{cl: val for (cl, val) in automated_classification_values}[cl].lower()] >= scale[min_value]
         else:
             return False
