@@ -1,82 +1,90 @@
+import json
 import logging
 import os
 import re
 import tempfile
+import urllib.request
 from typing import List, Tuple, Union
+from urllib.error import HTTPError
 
 import numpy as np
 
 from collections import defaultdict
-from pdfminer.high_level import extract_text
-from fabric.connection import Connection
-from pdfminer.layout import LAParams
+
+import requests
+from grobid_client import Client
+from pathlib import Path
+from grobid_client.api.pdf import process_fulltext_document
+from grobid_client.models import Article, ProcessForm
+from grobid_client.types import TEI, File
+
 
 from wbtools.db.afp import WBAFPDBManager
 from wbtools.db.paper import WBPaperDBManager
 from wbtools.db.person import WBPersonDBManager
 from wbtools.lib.nlp.entity_extraction.email_addresses import get_email_addresses_from_text
 from wbtools.lib.nlp.text_preprocessing import preprocess, get_documents_from_text, PaperSections
-from wbtools.lib.scraping import get_supp_file_names_from_paper_dir, download_pdf_file_from_url
 from wbtools.lib.timeout import timeout
 from wbtools.literature.person import WBAuthor
+from wbtools.utils.okta_utils import get_authentication_token, generate_headers
 
 logger = logging.getLogger(__name__)
 
 logging.getLogger("pdfminer").setLevel(logging.WARNING)
 
+ABC_API = os.environ.get('API_SERVER', "literature-rest.alliancegenome.org")
 
-class PaperFileReader(object):
 
-    def __init__(self, host: str = "https://tazendra.caltech.edu/~acedb/daniel/", user: str = '', password: str = ''):
-        self.host = host
-        self.user = user
-        self.passwd = password
-
-    @staticmethod
-    @timeout(3600)
-    def convert_pdf_to_txt(file_path):
-        try:
-            logger.info("Started pdf to text conversion")
-            laparams = LAParams(char_margin=100)
-            text = extract_text(file_path, laparams=laparams)
-            return text if text is not None else ""
-        except:
-            return ""
-
-    def get_supplemental_file_names(self, supp_dir_path):
-        return get_supp_file_names_from_paper_dir(self.host.rstrip("/") + "/" + supp_dir_path, self.user, self.passwd)
-
-    def download_paper_and_extract_txt(self, file_url, pdf: bool = False):
-        try:
-            tmp_file = download_pdf_file_from_url(file_url, self.user, self.passwd)
-            if pdf:
-                return self.convert_pdf_to_txt(tmp_file.name)
+@timeout(3600)
+def convert_pdf_to_txt(file_path):
+    client = Client(base_url=os.environ.get("GROBID_API_URL", "http://cervino.caltech.edu:8070/api"), timeout=1000,
+                    verify_ssl=False)
+    try:
+        logger.info("Started pdf to text conversion")
+        pdf_file = Path(file_path)
+        with pdf_file.open("rb") as fin:
+            form = ProcessForm(
+                segment_sentences="1",
+                input_=File(file_name=pdf_file.name, payload=fin, mime_type="application/pdf"))
+            r = process_fulltext_document.sync_detailed(client=client, multipart_data=form)
+            if r.is_success:
+                article: Article = TEI.parse(r.content, figures=False)
+                return [re.sub('<[^<]+>', '', sentence.text) for section in article.sections for paragraph
+                        in section.paragraphs for sentence in paragraph if not (
+                            len(section.paragraphs) == 1 and len(section.paragraphs[0]) == 3 and
+                            section.paragraphs[0][0].text == '\n' and section.paragraphs[0][-1].text == '\n')]
             else:
-                return open(tmp_file.name).read()
-        except FileNotFoundError:
-            logger.warning("File not found: " + file_url)
-            return ""
+                return []
+    except:
+        return []
 
-    def get_text_from_file(self, dir_path, supp_dir, filename, remote_file: bool = False, pdf: bool = False):
-        if remote_file:
-            text = self.download_paper_and_extract_txt(self.host.rstrip("/") + "/" + supp_dir + filename, pdf)
+
+def get_data_from_url(url, headers=None, file_type='json'):
+    try:
+        response = requests.request("GET", url, headers=headers)
+        # response.raise_for_status()  # Check if the request was successful
+        if file_type == 'pdf':
+            return response.content
         else:
-            with open(os.path.join(dir_path, filename), 'r') as file:
-                text = file.read()
-        if np.average([len(w) for w in preprocess(text).split("\n")]) < 1.001:
-            text = text.replace("\n\n", " ")
-        return text
+            content = response.json()
+            if content is None:
+                content = response.text()
+            return content
+    except requests.exceptions.RequestException as e:
+        logger.info(f"Error occurred for accessing/retrieving data from {url}: error={e}")
+        return None
 
 
 class WBPaper(object):
     """WormBase paper information"""
 
-    def __init__(self, paper_id: str = '', main_text: str = '', ocr_text: str = '', temp_text: str = '',
-                 aut_text: str = '', html_text: str = '', proof_text: str = '', supplemental_docs: list = None,
-                 file_server_host: str = 'https://tazendra.caltech.edu/~acedb/daniel/', file_server_user: str = '',
-                 file_server_passwd: str = '', title: str = '', journal: str = '', pub_date: str = '',
+    def __init__(self, agr_curie: str = '', paper_id: str = '', main_text: List[str] = '', ocr_text: List[str] = '',
+                 temp_text: List[str] = '', aut_text: List[str] = '', html_text: List[str] = '',
+                 proof_text: List[str] = '',
+                 supplemental_docs: list = None, title: str = '', journal: str = '', pub_date: str = '',
                  authors: List[WBAuthor] = None, abstract: str = '', doi: str = '', pmid: str = '',
                  db_manager: WBPaperDBManager = None):
+        self.agr_curie = agr_curie
         self.paper_id = paper_id
         self.title = title
         self.journal = journal
@@ -93,8 +101,6 @@ class WBPaper(object):
         self.proof_text = proof_text
         self.supplemental_docs = supplemental_docs if supplemental_docs else []
         self.aut_class_values = defaultdict(str)
-        self.paper_file_reader = PaperFileReader(host=file_server_host, user=file_server_user,
-                                                 password=file_server_passwd)
         self.afp_final_submission = False
         self.afp_processed = False
         self.afp_partial_submission = False
@@ -113,17 +119,13 @@ class WBPaper(object):
                 return author
         return None
 
-    def get_text_docs(self, include_supplemental: bool = True, remove_sections: List[PaperSections] = None,
-                      must_be_present: List[PaperSections] = None, split_sentences: bool = False,
+    def get_text_docs(self, include_supplemental: bool = True, split_sentences: bool = False,
                       lowercase: bool = False, tokenize: bool = False, remove_stopwords: bool = False,
                       remove_alpha: bool = False, return_concatenated: bool = False) -> Union[List[str], str]:
         """get text documents for the paper
 
         Args:
             include_supplemental (bool): include supplemental material
-            remove_sections (List[PaperSections]): sections to be removed
-            must_be_present (List[PaperSections]): sections that must be present in the text to be able to remove
-                                                   undesired sections
             split_sentences (bool): split documents into sections
             lowercase (bool): transform text to lowercase
             tokenize (bool): tokenize text into words
@@ -141,9 +143,7 @@ class WBPaper(object):
                 self.proof_text]
         if include_supplemental:
             docs.extend(self.supplemental_docs)
-        docs = [d for doc in docs for d in get_documents_from_text(
-            text=doc, split_sentences=split_sentences, must_be_present=must_be_present,
-            remove_sections=remove_sections)]
+        docs = [d for doc in docs for d in get_documents_from_text(sentences=doc, split_sentences=split_sentences)]
         docs = [preprocess(doc, lower=lowercase, tokenize=tokenize, remove_stopwords=remove_stopwords,
                            remove_alpha=remove_alpha) for doc in docs]
         if return_concatenated:
@@ -151,71 +151,56 @@ class WBPaper(object):
         else:
             return docs
 
-    def add_file(self, dir_path, filename, remote_file: bool = False, pdf: bool = False):
-        """add one or more files to the paper. Information about the type of file is derived from file name. If the file
-           path points to a directory, all supplementary files in it are loaded.
-
-        Args:
-            dir_path (str): path to the base directory
-            filename (str): name of the file to load
-            remote_file (bool): whether the file is on a remote location
-            pdf (bool): whether the file is in pdf format
-        """
-        all_supp = False
-        sup_dir = ""
-        if not self.paper_file_reader and remote_file:
-            raise Exception("a paper reader must be provided to access remote files")
-        if dir_path.endswith("supplemental/") and re.match(r'^[0-9]+$', filename):
-            filenames = self.paper_file_reader.get_supplemental_file_names(filename)
-            dir_path = dir_path + filename + "/"
-            sup_dir = "/" + filename + "/"
-            all_supp = True
+    def add_file_from_abc_reffile_obj(self, referencefile_json_obj):
+        file_download_api = (f"https://{ABC_API}/reference/referencefile/download_file/"
+                             f"{referencefile_json_obj['referencefile_id']}")
+        token = get_authentication_token()
+        headers = generate_headers(token)
+        paper_content = get_data_from_url(file_download_api, headers, file_type='pdf')
+        with tempfile.NamedTemporaryFile() as tmp_file:
+            tmp_file.write(paper_content)
+            text_content = convert_pdf_to_txt(tmp_file.name)
+        if not text_content:
+            return False
+        if referencefile_json_obj['file_class'] == 'supplement':
+            sup_doc = text_content
+            self.supplemental_docs.append(sup_doc)
         else:
-            filenames = [filename]
-        for filename in filenames:
-            logger.info("Adding file " + dir_path + filename)
-            if "_lib" not in filename and "Fig" not in filename and "Figure" not in filename:
-                wb_paperid, author_year, additional_options = self._get_matches_from_filename(filename)
-                if not self.paper_id:
-                    self.paper_id = wb_paperid
-                if all_supp or (author_year and ("_supp" in author_year or "_Supp" in author_year or "_Table" in
-                                                 author_year or "_table" in author_year or "_mmc" in author_year or
-                                                 "_Stable" in author_year or "_Movie" in author_year or "_movie" in
-                                                 author_year or "supplementary" in author_year or "Supplementary" in
-                                                 author_year or re.match(r'[_-][Ss][0-9]+', author_year))):
-                    self.supplemental_docs.append(self.paper_file_reader.get_text_from_file(
-                        dir_path, sup_dir, filename, remote_file, pdf))
-                    return
-                if not additional_options:
-                    self.main_text = self.paper_file_reader.get_text_from_file(dir_path, sup_dir, filename, remote_file, pdf)
-                elif "Supp" in additional_options or "supp" in additional_options or "Table" in additional_options or \
-                        "table" in additional_options or "Movie" in additional_options or "movie" in additional_options:
-                    self.supplemental_docs.append(self.paper_file_reader.get_text_from_file(
-                        dir_path, sup_dir, filename, remote_file, pdf))
-                elif "ocr" in additional_options:
-                    self.ocr_text = self.paper_file_reader.get_text_from_file(dir_path, sup_dir, filename, remote_file, pdf)
-                elif "_proof" in additional_options:
-                    self.proof_text = self.paper_file_reader.get_text_from_file(dir_path, sup_dir, filename, remote_file, pdf)
-                elif "temp" in additional_options:
-                    self.temp_text = self.paper_file_reader.get_text_from_file(dir_path, sup_dir, filename, remote_file, pdf)
-                elif "aut" in additional_options:
-                    self.aut_text = self.paper_file_reader.get_text_from_file(dir_path, sup_dir, filename, remote_file, pdf)
-                elif "html" in additional_options:
-                    self.html_text = self.paper_file_reader.get_text_from_file(dir_path, sup_dir, filename, remote_file, pdf)
-                else:
-                    logger.warning("No rule to read filename: " + filename)
+            if referencefile_json_obj['file_publication_status'] == 'temp':
+                self.temp_text = text_content
+            elif referencefile_json_obj['pdf_type'] == 'ocr':
+                self.ocr_text = text_content
+            elif referencefile_json_obj['pdf_type'] == 'aut':
+                self.aut_text = text_content
+            elif referencefile_json_obj['pdf_type'] == 'html':
+                self.html_text = text_content
+            else:
+                self.main_text = text_content
+        return True
 
-    def load_text_from_pdf_files_in_db(self):
-        """load text from pdf files in the WormBase database"""
+    def load_text_from_pdf_files(self, main_file_only):
         if self.db_manager:
-            file_paths = self.db_manager.get_file_paths(self.paper_id)
-            for file_path in file_paths:
-                filename = file_path.split("/")[-1]
-                if filename.lower().endswith(".pdf") or re.match(r'^[0-9]+$', filename):
-                    dir_path = file_path.rstrip(filename)
-                    self.add_file(dir_path=dir_path, filename=filename, remote_file=True, pdf=True)
-        else:
-            raise Exception("PaperDBManager not set")
+            blue_api_base_url = os.environ.get('API_SERVER', "literature-rest.alliancegenome.org")
+            all_reffiles_for_pap_api = f'https://{blue_api_base_url}/reference/referencefile/show_all/{self.agr_curie}'
+            request = urllib.request.Request(url=all_reffiles_for_pap_api)
+            request.add_header("Content-type", "application/json")
+            request.add_header("Accept", "application/json")
+            added_ref_files = 0
+            try:
+                with urllib.request.urlopen(request) as response:
+                    resp = response.read().decode("utf8")
+                    resp_obj = json.loads(resp)
+                    for ref_file in resp_obj:
+                        if ref_file["file_extension"] == "pdf" and any(
+                                ref_file_mod["mod_abbreviation"] in [None, "WB"] for ref_file_mod in
+                                ref_file["referencefile_mods"]) and (
+                                not main_file_only or ref_file["file_class"] == "main"):
+                            if self.add_file_from_abc_reffile_obj(ref_file):
+                                added_ref_files += 1
+            except HTTPError as e:
+                logger.error(e)
+                return False
+            return added_ref_files > 0
 
     def load_curation_info_from_db(self):
         """load curation data from WormBase database"""
@@ -226,18 +211,22 @@ class WBPaper(object):
         else:
             raise Exception("PaperDBManager not set")
 
-    def load_bib_info_from_db(self):
-        """load curation data from WormBase database"""
-        if self.db_manager:
-            self.abstract = self.db_manager.get_paper_abstract(self.paper_id)
-            self.title = self.db_manager.get_paper_title(self.paper_id)
-            self.journal = self.db_manager.get_paper_journal(self.paper_id)
-            self.pub_date = self.db_manager.get_paper_pub_date(self.paper_id)
-            self.authors = self.db_manager.get_paper_authors(self.paper_id)
-            self.doi = self.db_manager.get_doi(self.paper_id)
-            self.pmid = self.db_manager.get_pmid(self.paper_id)
-        else:
+    def load_bib_info(self):
+        """Load bibliographical info from ABC"""
+        if not self.db_manager:
             raise Exception("PaperDBManager not set")
+        # Get Alliance reference info from WBPaperID
+        ref_info_from_xref_api = f"https://{ABC_API}/reference/by_cross_reference/WB:WBPaper{self.paper_id}"
+        ref_info: dict = get_data_from_url(ref_info_from_xref_api)
+        self.abstract = ref_info["abstract"]
+        self.title = ref_info["title"]
+        self.journal = ref_info["resource_title"]
+        self.pub_date = ref_info["date_published"]
+        # Getting author data from db until ABC has author-person info
+        self.authors = self.db_manager.get_paper_authors(paper_id=self.paper_id)
+        self.doi = [xref["curie"] for xref in ref_info["cross_references"] if xref["curie_prefix"] == "DOI"][0]
+        self.pmid = [xref["curie"] for xref in ref_info["cross_references"] if xref["curie_prefix"] == "PMID"][0]
+        self.agr_curie = ref_info["curie"]
 
     def load_afp_info_from_db(self, paper_ids_no_submission: List[str] = None,
                               paper_ids_full_submission: List[str] = None,
